package main

import (
	"net/http"
	"sprechstundentool/controllers"
	"sprechstundentool/repositories"
	"sprechstundentool/sqldb"
)

func main() {
	db := sqldb.ConnectDB()

	// Create repos
	roomRepo := repositories.NewRoomRepo(db)
	courseRepo := repositories.NewCourseRepo(db)
	tutorRepo := repositories.NewTutorRepo(db)
	officeHourRepo := repositories.NewOfficeHourRepo(db, roomRepo, tutorRepo, courseRepo)
	requestRepo := repositories.NewRequestRepo(db, officeHourRepo)
	h := controllers.NewBaseHandler(roomRepo, officeHourRepo, courseRepo, tutorRepo, requestRepo)

	http.HandleFunc("/getByRoom", h.GetByRoomHandler)
	http.HandleFunc("/getByCourse", h.GetByCourseHandler)
	http.HandleFunc("/addOfficeHour", h.AddOfficeHourHandler)
	http.HandleFunc("/confirmRequest", h.ConfirmRequestHandler)
	http.HandleFunc("/deleteOfficeHour", h.DeleteOfficeHourHandler)
	http.HandleFunc("/", h.RootHandler)

	http.ListenAndServe(":8080", nil)

}
